@@ -10,7 +10,6 @@ describe 'cinder::backend::nfs' do
       :nfs_mount_attempts          => '4',
       :nfs_mount_options           => 'vers=3',
       :nfs_shares_config           => '/etc/cinder/other_shares.conf',
-      :nfs_disk_util               => 'du',
       :nfs_sparsed_volumes         => true,
       :nfs_mount_point_base        => '/cinder_mount_point',
       :nfs_used_ratio              => '0.7',
@@ -33,7 +32,6 @@ describe 'cinder::backend::nfs' do
         is_expected.to contain_cinder_config('hippo/nfs_mount_options').with_value('vers=3')
         is_expected.to contain_cinder_config('hippo/nfs_sparsed_volumes').with_value(true)
         is_expected.to contain_cinder_config('hippo/nfs_mount_point_base').with_value('/cinder_mount_point')
-        is_expected.to contain_cinder_config('hippo/nfs_disk_util').with_value('du')
         is_expected.to contain_cinder_config('hippo/nfs_used_ratio').with_value('0.7')
         is_expected.to contain_cinder_config('hippo/nfs_oversub_ratio').with_value('0.9')
         is_expected.to contain_cinder_config('hippo/nas_secure_file_operations').with_value('auto')
